import { Signal } from '@angular/core';
import { CallableObject } from '@s-libs/js-core';
import { buildChild } from './child-store';
import { GetSlice, Slice, Store } from './store';
export interface AbstractStore<T> {
    <K extends keyof NonNullable<T>>(attr: K): Slice<T, K>;
}
export declare abstract class AbstractStore<T> extends CallableObject<GetSlice<T>> implements Store<T> {
    #private;
    private signal;
    /**
     * Assigns the given values to the state of this store object. The resulting state will be like `Object.assign(store.state, value)`.
     */
    assign: import("./interfaces").IfCouldBe<T, any[] | import("./interfaces").Nil | import("./interfaces").Primitive, never, (value: Partial<T>) => void>;
    constructor(signal: Signal<T>, makeChild: typeof buildChild);
    get nonNull(): Store<NonNullable<T>>;
    /**
     * Get the current state of this store object. This is backed by a signal, so it will trigger change detection when accessed in templates, etc.
     */
    get state(): T;
    /**
     * Change the value of this store. Following the pattern of immutable objects, the parent store will also update with shallow copy but with this value swapped in, and so on for all ancestors.
     */
    set state(value: T);
    /**
     * Runs `func` on the state and replaces it with the return value. The first argument to `func` will be the state, followed by the arguments in `args`.
     *
     * WARNING: You SHOULD NOT use a function that will mutate the state.
     */
    update<A extends any[]>(func: (state: T, ...args: A) => T, ...args: A): void;
    /**
     * Runs `func` on a shallow clone of the state, replacing the state with the clone. The first argument to `func` will be the cloned state, followed by the arguments in `args`.
     *
     * WARNING: You SHOULD NOT use a function that will mutate nested objects within the state.
     */
    mutate<A extends any[]>(func: (state: T, ...args: A) => void, ...args: A): void;
    protected abstract set(value: T): void;
}
